# README

This is the second major assignment of the fourth group.

___

### **Division of labor among team members**

Feng Chenwei 2021130609109:Obtaining Data , **Project Selection**

Huawen 2021130609110, Zhao Haoran 202113060906:**Process data**, **Write code**

Ai Shan Wusman 202113060911:**Team Member Assignment**,**Explanation Document**

Li Wenkai 201913061007:**Project Explanation**

### Step

1. firstDataAnalysis
2. secondDataProcessing
3. thirdTransformData
4. forthUserAnalysis
5. fifthCreateDatabase
6. sisthDataPersistence

